@@ -2,7 +2,7 @@
 
 echo "--------------------------------------------------------------------"
 echo
-echo "SoftEther VPN Client (Ver 4.38, Build 9760, Intel x64 / AMD64) for Linux Build Utility"
+echo "SoftEther VPN Client (Ver 4.44, Build 9807, Intel x86) for Linux Build Utility"
 echo "Copyright (c) SoftEther Project at University of Tsukuba, Japan. All Rights Reserved."
 echo
 echo "--------------------------------------------------------------------"
